.. lleaves documentation master file, created by
   sphinx-quickstart on Sun May 30 14:46:31 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

lleaves 🍃
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   development.rst
   API Reference <api/modules>

.. autoclass:: lleaves.Model
   :members:
   :noindex:

   .. automethod:: __init__

